@@ -7,6 +7,7 @@ from aiohttp.formdata import FormData
 from aiohttp.client import ClientTimeout
 from etools.singleton_meta import SingletonMeta
 from etools.http_common import convert_file_args
+from aiohttp import TCPConnector
 
 
 class AsyncHttpClient(metaclass=SingletonMeta):
@@ -16,7 +17,7 @@ class AsyncHttpClient(metaclass=SingletonMeta):
 
     async def init(self):
         if self.session is None:
-            self.session = aiohttp.ClientSession()
+            self.session = aiohttp.ClientSession(connector=TCPConnector(verify_ssl=False))
 
     async def destroy(self):
         if self.session is not None:
@@ -24,22 +25,28 @@ class AsyncHttpClient(metaclass=SingletonMeta):
             self.session = None
 
     async def get(self, url, headers=None, timeout=5, timeout_retry=3,
-                  decode_json=True, **kwargs):
+                  decode_json=True, return_binary=False, **kwargs):
         return await self.request("get", url, None, headers, None,
-                                  timeout, timeout_retry, decode_json, **kwargs)
+                                  timeout, timeout_retry, decode_json,
+                                  return_binary, **kwargs)
 
     async def post(self, url, data, headers=None,
-                   timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+                   timeout=5, timeout_retry=3, decode_json=True,
+                   return_binary=False, **kwargs):
         return await self.request("post", url, data, headers, None,
-                                  timeout, timeout_retry, decode_json, **kwargs)
+                                  timeout, timeout_retry, decode_json,
+                                  return_binary, **kwargs)
 
     async def post_form(self, url, data, files, headers=None,
-                        timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+                        timeout=5, timeout_retry=3, decode_json=True,
+                        return_binary=False,**kwargs):
         return await self.request("post", url, data, headers, files,
-                                  timeout, timeout_retry, decode_json, **kwargs)
+                                  timeout, timeout_retry, decode_json,
+                                  return_binary, **kwargs)
 
     async def request(self, method, url, data=None, headers=None, files=None,
-                      timeout=5, timeout_retry=3, decode_json=True, **kwargs):
+                      timeout=5, timeout_retry=3, decode_json=True,
+                      return_binary=False, **kwargs):
         for _ in range(timeout_retry):
             try:
                 post_data = data
@@ -58,15 +65,18 @@ class AsyncHttpClient(metaclass=SingletonMeta):
                 func = getattr(self.session, method)
                 async with func(url, data=post_data, headers=headers,
                                 timeout=ClientTimeout(timeout), **kwargs) as resp:
-                    result = await resp.text(encoding='UTF-8')
                     if resp.status != 200:
                         self.logger.error(
                             "[%s] url[%s], data[%s] headers[%s] kwargs[%s] failed,"\
                             " code[%d], response[%s]",
                             method, url, post_data, headers, kwargs, resp.status, result)
                         return None
-                    if decode_json:
-                        result = json.loads(result)
+                    if return_binary:
+                        result = await resp.content.read()
+                    else:
+                        result = await resp.text(encoding='UTF-8')
+                        if decode_json:
+                            result = json.loads(result)
                     return result
             except asyncio.TimeoutError:
                 self.logger.warning(
